package common

type ViewRange struct {
	Width         int
	Height        int
	Start         int
	FirstRowIndex int
	LastRowIndex  int
}
